==> nextcloud-29.0.9.tgz: nextcloud/apps/files_downloadlimit/l10n/ug.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "ھۆججەتلەرنى چۈشۈرۈش چېكى",
    "File link share download limit" : "ھۆججەت ئۇلانمىسىنى چۈشۈرۈش چېكى",
    "This app allows limiting the number of downloads for external link shares." : "بۇ ئەپ سىرتقى ئۇلىنىش ھەمبەھىرلىرىنىڭ چۈشۈرۈش سانىنى چەكلەشكە يول قويىدۇ.",
    "Limit downloads" : "چۈشۈرۈشنى چەكلەڭ",
    "Set download limit" : "چۈشۈرۈش چەكلىمىسىنى بەلگىلەڭ",
    "Setting a new limit will reset the download count" : "يېڭى چەك بەلگىلەش چۈشۈرۈش سانىنى ئەسلىگە كەلتۈرىدۇ",
    "The minimum limit is 1" : "ئەڭ تۆۋەن چەك 1",
    "Failed to set download limit" : "چۈشۈرۈش چەكلىمىسىنى بەلگىلىمىدى",
    "Failed to remove download limit" : "چۈشۈرۈش چەكلىمىسىنى ئۆچۈرەلمىدى",
    "Download limit" : "چۈشۈرۈش چېكى",
    "Configure the default download limit for external shares." : "سىرتقى پايلارنىڭ سۈكۈتتىكى چۈشۈرۈش چېكىنى تەڭشەڭ.",
    "Set default download limit" : "سۈكۈتتىكى چۈشۈرۈش چەكلىمىسىنى بەلگىلەڭ",
    "Failed to set default download limit" : "سۈكۈتتىكى چۈشۈرۈش چېكى بېكىتىلمىدى",
    "You have reached the maximum amount of downloads allowed" : "چۈشۈرۈشكە رۇخسەت قىلىنغان ئەڭ يۇقىرى چەككە يەتتىڭىز",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "بۇ ھەمبەھىرنىڭ چۈشۈرۈش سانى چەكلىك. يېڭى چۈشۈرۈشنى قوزغىتىشنى خالامسىز؟",
    "Allow to limit the number of downloads for link shares" : "ئۇلىنىش ھەمبەھىرلىرىنىڭ چۈشۈرۈش سانىنى چەكلەشكە يول قويۇڭ",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "بۇ ئۈلۈش {چەك} چۈشۈرۈش بىلەنلا چەكلەندى. يەنىلا {countLeft} قالدى."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.11.tgz: nextcloud/apps/files_downloadlimit/l10n/ug.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "ھۆججەتلەرنى چۈشۈرۈش چېكى",
    "File link share download limit" : "ھۆججەت ئۇلانمىسىنى چۈشۈرۈش چېكى",
    "This app allows limiting the number of downloads for external link shares." : "بۇ ئەپ سىرتقى ئۇلىنىش ھەمبەھىرلىرىنىڭ چۈشۈرۈش سانىنى چەكلەشكە يول قويىدۇ.",
    "Limit downloads" : "چۈشۈرۈشنى چەكلەڭ",
    "Set download limit" : "چۈشۈرۈش چەكلىمىسىنى بەلگىلەڭ",
    "Setting a new limit will reset the download count" : "يېڭى چەك بەلگىلەش چۈشۈرۈش سانىنى ئەسلىگە كەلتۈرىدۇ",
    "The minimum limit is 1" : "ئەڭ تۆۋەن چەك 1",
    "Failed to set download limit" : "چۈشۈرۈش چەكلىمىسىنى بەلگىلىمىدى",
    "Failed to remove download limit" : "چۈشۈرۈش چەكلىمىسىنى ئۆچۈرەلمىدى",
    "Download limit" : "چۈشۈرۈش چېكى",
    "Configure the default download limit for external shares." : "سىرتقى پايلارنىڭ سۈكۈتتىكى چۈشۈرۈش چېكىنى تەڭشەڭ.",
    "Set default download limit" : "سۈكۈتتىكى چۈشۈرۈش چەكلىمىسىنى بەلگىلەڭ",
    "Failed to set default download limit" : "سۈكۈتتىكى چۈشۈرۈش چېكى بېكىتىلمىدى",
    "You have reached the maximum amount of downloads allowed" : "چۈشۈرۈشكە رۇخسەت قىلىنغان ئەڭ يۇقىرى چەككە يەتتىڭىز",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "بۇ ھەمبەھىرنىڭ چۈشۈرۈش سانى چەكلىك. يېڭى چۈشۈرۈشنى قوزغىتىشنى خالامسىز؟",
    "Allow to limit the number of downloads for link shares" : "ئۇلىنىش ھەمبەھىرلىرىنىڭ چۈشۈرۈش سانىنى چەكلەشكە يول قويۇڭ",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "بۇ ئۈلۈش {limit} چۈشۈرۈش بىلەنلا چەكلەندى. يەنىلا {countLeft} قالدى."
},
"nplurals=2; plural=(n != 1);");
